@@ -192,7 +192,7 @@ impl PostParams {
 /// use k8s_openapi::apimachinery::pkg::apis::meta::v1::ObjectMeta;
 /// let r = Role {
 ///     metadata: ObjectMeta { name: Some("user".into()), ..ObjectMeta::default() },
-///     rules: Some(vec![])
+///     rules: vec![]
 /// };
 /// let patch = Patch::Apply(&r);
 /// ```
@@ -294,8 +294,8 @@ impl PatchParams {
         if self.force {
             qp.append_pair("force", "true");
         }
-        if let Some(ref field_manager) = self.field_manager {
-            qp.append_pair("fieldManager", &field_manager);
+        if let Some(ref fm) = self.field_manager {
+            qp.append_pair("fieldManager", fm);
         }
     }
 
